==> amity-sdk-7.12.4-sources.jar: main/com/amity/socialcloud/sdk/video/data/room/RoomModelMapper.kt <==
package com.amity.socialcloud.sdk.video.data.room

import com.amity.socialcloud.sdk.common.ModelMapper
import com.amity.socialcloud.sdk.entity.video.room.RoomEntity
import com.amity.socialcloud.sdk.model.video.room.AmityRoom
import com.amity.socialcloud.sdk.model.video.room.AmityRoomStatus
import com.amity.socialcloud.sdk.model.video.room.AmityRoomType
import com.google.gson.JsonObject
import kotlin.collections.mapNotNull

internal class RoomModelMapper : ModelMapper<RoomEntity, AmityRoom>() {

    override fun map(entity: RoomEntity): AmityRoom {
        return entity.run {
            AmityRoom(
                roomId = roomId,
                type = AmityRoomType.enumOf(type),
                targetType = targetType,
                targetId = targetId,
                referenceType = referenceType,
                referenceId = referenceId,
                channelEnabled = channelEnabled,
                channelId = channelId,
                title = title,
                description = description,
                thumbnailFileId = thumbnailFileId,
                status = AmityRoomStatus.enumOf(status),
                livePlaybackUrl = livePlaybackUrl,
                durationSeconds = durationSeconds,
                parentRoomId = parentRoomId,
                childRoomIds = childRoomIds ?: emptyList(),
                creatorId = creatorId,
                isDeleted = isDeleted,
                metadataJson = metadata,
                createdAt = createdAt,
                updatedAt = updatedAt,
                liveAt = liveAt,
                endedAt = endedAt,
                recordedAt = recordedAt,
                recordedUrl = recordedUrl,
                recordedThumbnailUrl = recordedThumbnailUrl,
                childRooms = emptyList(),
                path = path ?: "",
                participants = participants?.mapNotNull { participant ->
                    (participant as? JsonObject)?.let {
                        val userId = participant.get("userId")?.asString
                        val type = participant.get("type")?.asString
                        if (userId != null && type != null) userId to type else null
                    }
                }?.map { participant ->
                    AmityRoom.Participant(
                        type = AmityRoom.ParticipantType.enumOf(participant.first),
                        userId = participant.second,
                    )
                } ?: emptyList()
            )
        }
    }
}

==> amity-sdk-7.13.1-sources.jar: main/com/amity/socialcloud/sdk/video/data/room/RoomModelMapper.kt <==
package com.amity.socialcloud.sdk.video.data.room

import com.amity.socialcloud.sdk.common.ModelMapper
import com.amity.socialcloud.sdk.entity.video.room.RoomEntity
import com.amity.socialcloud.sdk.model.video.room.AmityRoom
import com.amity.socialcloud.sdk.model.video.room.AmityRoomStatus
import com.amity.socialcloud.sdk.model.video.room.AmityRoomType
import com.google.gson.JsonObject
import kotlin.collections.mapNotNull

internal class RoomModelMapper : ModelMapper<RoomEntity, AmityRoom>() {

    override fun map(entity: RoomEntity): AmityRoom {
        return entity.run {
            AmityRoom(
                roomId = roomId,
                type = AmityRoomType.enumOf(type),
                targetType = targetType,
                targetId = targetId,
                referenceType = referenceType,
                referenceId = referenceId,
                channelEnabled = channelEnabled,
                channelId = channelId,
                title = title,
                description = description,
                thumbnailFileId = thumbnailFileId,
                status = AmityRoomStatus.enumOf(status),
                livePlaybackUrl = livePlaybackUrl,
                durationSeconds = durationSeconds,
                parentRoomId = parentRoomId,
                childRoomIds = childRoomIds ?: emptyList(),
                creatorId = creatorId,
                isDeleted = isDeleted,
                metadataJson = metadata,
                createdAt = createdAt,
                updatedAt = updatedAt,
                liveAt = liveAt,
                endedAt = endedAt,
                recordedAt = recordedAt,
                recordedUrl = recordedUrl,
                recordedThumbnailUrl = recordedThumbnailUrl,
                childRooms = emptyList(),
                path = path ?: "",
                participants = participants?.mapNotNull { participant ->
                    (participant as? JsonObject)?.let {
                        val userId = participant.get("userId")?.asString
                        val type = participant.get("type")?.asString
                        val userInternalId = participant.get("userInternalId")?.asString
                        if (userId != null && type != null) {
                            AmityRoom.Participant(
                                    type = AmityRoom.ParticipantType.enumOf(type),
                                    userId = userId,
                                    userInternalId = userInternalId,
                            )
                        } else {
                            null
                        }
                    }
                } ?: emptyList()
            )
        }
    }
}
